import SwiftUI

struct ContentView: View {
    var body: some View {
        NavigationView {
            List {
                Section {
                    ForEach(sections) { section in
                        NavigationLink(destination: section.destination) {
                            MenuItemView(text: section.text,
                                         icon: section.icon,
                                         color: section.color)
                        }
                    }
                }
                
                Section {
                    NavigationLink(destination: BookView()) {
                        MenuItemView(text: "Playground Book",
                                     icon: "book.fill",
                                     color: .brown)
                    }
                }
            }
            .navigationBarTitle("Assets")
        }
        .listStyle(.sidebar)
    }
}

#Preview("Assets List View") {
    ContentView()
        .preferredColorScheme(.none)
}

struct MenuItemView: View {
    let text: String
    let icon: String
    let color: Color
    
    var body: some View {
        HStack {
            IconView(icon: icon,
                     color: color)
            Text(text)
        }
    }
}

struct IconView: View {
    let icon: String
    let color: Color
    
    var body: some View {
        RoundedRectangle(cornerRadius: 8)
            .fill(color)
            .frame(width: 40, height: 40)
            .overlay(
                Image(systemName: icon)
                    .font(.system(size: 20))
                    .foregroundStyle(.white)
            )
            .padding(.trailing, 8)
    }
}

struct SectionInfo: Identifiable {
    let id = UUID()
    let text: String
    let icon: String
    let color: Color
    let destination: AnyView
}

let sections = [
    SectionInfo(text: "Project structure",
                icon: "folder.fill",
                color: .red,
                destination: AnyView(StructureView())),
    SectionInfo(text: "Add color",
                icon: "swatchpalette.fill",
                color: .green,
                destination: AnyView(ColorSetView())),
    SectionInfo(text: "Add image",
                icon: "photo.on.rectangle.angled",
                color: .blue,
                destination: AnyView(ImageSetView())),
    SectionInfo(text: "Use custom fonts",
                icon: "textformat",
                color: .purple,
                destination: AnyView(CustomFontsView())),
    SectionInfo(text: "Localization strings",
                icon: "bubble.left.and.bubble.right.fill",
                color: .orange,
                destination: AnyView(LocalizationView()))
]
